///
/// @file
/// Declares macros for the facter library version.
///
#pragma once

///
/// The facter library major version.
///
#define LIBFACTER_VERSION_MAJOR 3
///
/// The facter library minor version.
///
#define LIBFACTER_VERSION_MINOR 14
///
/// The facter library patch version.
///
#define LIBFACTER_VERSION_PATCH 22

///
/// The facter library version as a string (without commit SHA1).
///
#define LIBFACTER_VERSION "3.14.22"

///
/// The facter library version as a string (with commit SHA1).
///
#define LIBFACTER_VERSION_WITH_COMMIT "3.14.22"
